@@ -120,6 +120,8 @@ MainWindow::initLogging ()
     logsTimer.start (3 * 1000);
     QObject::connect (&logsTimer, SIGNAL(timeout()),
                        this     , SLOT(onCleanupLogsArray()));
+
+    setStatus("Using qgvdial version 0.2.679");
 }//MainWindow::initLogging
 
 /** Log information to console and to log file
@@ -433,6 +435,15 @@ MainWindow::init ()
     this->setWindowIcon (icoQgv);
     clearSmsDestinations ();
 
+    // Save the temp store location for contact photos
+    QString strTempStore = osd.getAppDirectory();
+    QDir dirApp(strTempStore);
+    strTempStore += QDir::separator() + tr("temp");
+    if (!QFileInfo(strTempStore).exists ()) {
+        dirApp.mkdir ("temp");
+    }
+    oContacts.setTempStore(strTempStore);
+
 #if MOSQUITTO_CAPABLE
     // Connect the signals from the Mosquitto thread
     QObject::connect (&mqThread , SIGNAL(sigUpdateInbox()),
